document.addEventListener('DOMContentLoaded', () => {
  // Mobile menu toggle
  const mobileMenu = document.querySelector('.mobile-menu');
  const navLinks = document.querySelector('.nav-links');

  mobileMenu.addEventListener('click', () => {
    navLinks.classList.toggle('active');
    const spans = mobileMenu.querySelectorAll('span');
    spans.forEach(span => span.classList.toggle('active'));
  });

  // Smooth scrolling for navigation links
  document.querySelectorAll('a[href^="#"]').forEach(anchor => {
    anchor.addEventListener('click', function (e) {
      e.preventDefault();
      const target = document.querySelector(this.getAttribute('href'));
      if (target) {
        target.scrollIntoView({
          behavior: 'smooth'
        });
        // Close mobile menu if open
        navLinks.classList.remove('active');
      }
    });
  });

  // Microscope viewer zoom functionality
  let zoomLevel = 1;
  const zoomArea = document.querySelector('.zoom-area');
  const zoomIn = document.getElementById('zoomIn');
  const zoomOut = document.getElementById('zoomOut');

  zoomIn.addEventListener('click', () => {
    if (zoomLevel < 3) {
      zoomLevel += 0.5;
      updateZoom();
    }
  });

  zoomOut.addEventListener('click', () => {
    if (zoomLevel > 1) {
      zoomLevel -= 0.5;
      updateZoom();
    }
  });

  function updateZoom() {
    zoomArea.style.transform = `scale(${zoomLevel})`;
  }

  // Intersection Observer for animation
  const observer = new IntersectionObserver((entries) => {
    entries.forEach(entry => {
      if (entry.isIntersecting) {
        entry.target.classList.add('visible');
      }
    });
  }, {
    threshold: 0.1
  });

  document.querySelectorAll('.cell-card').forEach(card => {
    observer.observe(card);
  });
});
